Command Line Interface
======================
pyBiodatafuse automatically installs the command :code:`pyBiodatafuse`. See
:code:`pyBiodatafuse --help` for usage details.

.. click:: pyBiodatafuse.cli:main
   :prog: pyBiodatafuse
   :show-nested:
